==> kbibtex-trinity_14.0.4.orig.tar.xz: kbibtex-trinity-14.0.4/src/fileimporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILEIMPORTEREXTERNAL_H
#define BIBTEXFILEIMPORTEREXTERNAL_H

#include <fileimporter.h>
#include <file.h>
#include <settings.h>

class TQWaitCondition;
class TQProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class FileImporterExternal : public FileImporter
    {
        Q_OBJECT
    public:
        enum Importer {importerNone = 0, importerBibConv = 4};

        FileImporterExternal( Importer importer, File::FileFormat fileformat );
        ~FileImporterExternal();

        File* load( TQIODevice *iodevice );
        // FIXME: this is a stub:
        static bool guessCanDecode( const TQString & )
        {
            return TRUE;
        };

    public slots:
        void cancel();

    private:
        TQWaitCondition *wc;
        TQProcess *process;
        TQTextStream *writeTo;
        Importer m_importer;
        File::FileFormat m_fileformat;

        bool fetchInput( TQIODevice *input, TQBuffer &output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();
    };

}

#endif

==> kbibtex-trinity-14.0.9.tar.xz: kbibtex-trinity-14.0.9/src/fileimporterexternal.h <==
/***************************************************************************
*   Copyright (C) 2004-2006 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILEIMPORTEREXTERNAL_H
#define BIBTEXFILEIMPORTEREXTERNAL_H

#include "fileimporter.h"
#include "file.h"
#include "settings.h"

class TQWaitCondition;
class TQProcess;

namespace BibTeX
{

    /**
    @author Thomas Fischer
    */
    class FileImporterExternal : public FileImporter
    {
        Q_OBJECT
    public:
        enum Importer {importerNone = 0, importerBibConv = 4};

        FileImporterExternal( Importer importer, File::FileFormat fileformat );
        ~FileImporterExternal();

        File* load( TQIODevice *iodevice );
        // FIXME: this is a stub:
        static bool guessCanDecode( const TQString & )
        {
            return TRUE;
        };

    public slots:
        void cancel();

    private:
        TQWaitCondition *wc;
        TQProcess *process;
        TQTextStream *writeTo;
        Importer m_importer;
        File::FileFormat m_fileformat;

        bool fetchInput( TQIODevice *input, TQBuffer &output );

    private slots:
        void slotProcessExited();
        void slotReadProcessOutput();
        void slotWroteToStdin();
    };

}

#endif
